#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: X11-xft
version: 0.3.1
id: X11-xft-0.3.1-66243f513e17481887364faf36406e3d
key: X11xf_FOjH5rtqNQH621mGQFjM9W
license: LGPL
maintainer: clemens@endorphin.org
synopsis: Bindings to the Xft, X Free Type interface library, and some Xrender parts
description:
    Bindings to the Xft, X Free Type interface library, and some Xrender parts
category: Graphics
author: Clemens Fruhwirth
exposed: True
exposed-modules:
    Graphics.X11.Xft Graphics.X11.Xrender
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/X11-xft-0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/X11-xft-0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/X11-xft-0.3.1
hs-libraries: HSX11-xft-0.3.1-FOjH5rtqNQH621mGQFjM9W
extra-libraries:
    Xft
include-dirs: /usr/include/freetype2 /usr/include/libpng16
              /usr/include/harfbuzz /usr/include/glib-2.0
              /usr/lib/glib-2.0/include
depends:
    X11-1.6.1.2-e77778265c7135c63ab82aead415c843
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html: /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
